@@ -12,10 +12,11 @@ class QRAddress:
 
 
 class QRRequest:
-    def __init__(self, json_data=None, params=None, headers=None):
+    def __init__(self, json_data=None, params=None, headers=None, form=None):
         self.__json_data = json_data
         self.__params = params
         self.__headers = headers
+        self.__form = form
 
     def get_json_data(self): return self.__json_data
 
@@ -23,16 +24,27 @@ class QRRequest:
 
     def get_headers(self): return self.__headers
 
+    def get_form(self): return dict(self.__form) if self.__form is not None else dict()
+
     params = property(get_params)
     json_data = property(get_json_data)
     headers = property(get_headers)
 
     def get_args(self) -> dict:
-        return {
+        args = {
             'json': self.get_json_data(),
             'params': self.get_params(),
             'headers': self.get_headers(),
+            'data': self.get_form(),
         }
+        for a in 'json', 'params', 'data':
+            if len(args[a]) == 0:
+                args.pop(a)
+        if args['headers'].get('CONTENT_TYPE') is not None:
+            # clear content type in case if 'data' (form) field is present - it needs boundaries which are better to be recalculated
+            args['headers'] = dict(args['headers'])
+            args['headers'].pop('Content-Type')
+        return args
 
 
 @dataclass
